@@ -40,13 +40,12 @@ def statistics(
     batch_ids = [batch.get("batch_id") for batch in batches]
     box_stat = get_statistics_for_box_plot(adapter=adapter, batches=batch_ids, fields=box_plots)
     scatter_stat = get_statistics_for_scatter_plot(batches=batches, fields=scatter_plots)
-
     return templates.TemplateResponse(
         "statistics.html",
         context=dict(
             request=request,
             current_user=user,
-            ticks=list(range(1, nr_batches + 1)),
+            ticks=list(range(0, nr_batches)),
             nr_batches=nr_batches,
             batch_ids=batch_ids,
             box_stat=box_stat,
